Package: SANTA
Type: Package
Title: Spatial Analysis of Network Associations
Version: 2.49.0
Authors@R: person("Alex", "Cornish", role = c("cre","aut"),
             email = "alexcornish88@gmail.com")
Date: 17 June 2024
Imports: graphics, Matrix, methods, stats
Depends: R (>= 4.1), igraph
Suggests: BiocGenerics, BioNet, formatR, knitr, msm, org.Sc.sgd.db,
        markdown, rmarkdown, RUnit
Description: This package provides methods for measuring the strength of association between a network and a phenotype. It does this by measuring clustering of the phenotype across the network (Knet). Vertices can also be individually ranked by their strength of association with high-weight vertices (Knode).
License: GPL (>= 2)
LazyLoad: yes
VignetteBuilder: knitr
biocViews: Network, NetworkEnrichment, Clustering
BugReports: https://github.com/alexjcornish/SANTA
git_url: https://git.bioconductor.org/packages/SANTA
git_branch: devel
git_last_commit: 09482a2
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: yes
Packaged: 2026-04-29 00:49:43 UTC; biocbuild
Author: Alex Cornish [cre, aut]
Maintainer: Alex Cornish <alexcornish88@gmail.com>
