import(igraph, Matrix)
importFrom("graphics", "abline", "hist", "lines", "par", "polygon")
importFrom("methods", "is")
importFrom("stats", "pnorm", "quantile", "runif", "sd")

export(
	BinGraph,
	CreateGrid, 
	Compactness,
	DistGraph, 
	GraphDiffusion, 
	GraphMFPT,
	Knet, 
	Knode, 
	plot.Knet, 
	SpreadHits
)

S3method(plot, Knet)

useDynLib(SANTA)
